@@ -73,7 +73,6 @@ char* strcpy_safe_max( char* buf, const char* src, size_t buflen, int max )
     
     /* Make sure the buffer is always terminated, even at fill-ups: */
     buf[buflen-1]= '\0';
-
     return strncpy( buf, src, buflen-1 /*max charcount*/ );
 }
 
@@ -97,9 +96,7 @@ char* strcat_safe_max( char* buf, const char* src, size_t buflen, int max )
 
     /* 'strncat()' always terminates the buffer but the size param
        is charcount of 'src', not the size of the buffer! */
-
-    return strncat( buf, src, n );
-}
+    return strncat( buf, src, n );}
 
 
 /* Returns a localized text string ("Close" or "Help"), using
@@ -133,7 +130,9 @@ const gchar *helplib_ui_str( enum e_HelpStrId id )
                      (id==HELP_UI_TAG_NOTE) ? "help_tag_note" :
                      (id==HELP_UI_TAG_EXAMPLE) ? "help_tag_example" :
                      (id==HELP_UI_TAG_WARNING) ? "help_tag_warning" :
-                     (id==HELP_UI_TAG_IMPORTANT) ? "help_tag_important" : "" );
+                     (id==HELP_UI_TAG_IMPORTANT) ? "help_tag_important" :
+                     (id==HELP_UI_IA_SEE_ALSO) ? "help_ia_see_also" :
+                     (id==HELP_UI_NOT_EXIST) ? "help_ni_help_text_does_not_exist" : "" );
 
     return str;
 }
@@ -450,6 +449,7 @@ osso_return_t ossohelp_show( osso_context_t* osso,
 {
     osso_return_t rc;
     osso_rpc_t retval;
+    osso_return_t ret;
 
     if (!help_id) return OSSO_INVALID;
 
@@ -500,6 +500,7 @@ osso_return_t ossohelp_show( osso_context_t* osso,
                 ULOG_CRIT( "HelpLib: DBUS call to HelpUI failed: '%s'\n", 
                            retval.value.s );
             }
+            osso_rpc_free_val(&retval);
             return OSSO_RPC_ERROR;
 
         case OSSO_RPC_ERROR:    /* Unable to reach? */
@@ -507,11 +508,13 @@ osso_return_t ossohelp_show( osso_context_t* osso,
                 ULOG_CRIT( "HelpLib: DBUS call to HelpUI failed: '%s'\n", 
                            retval.value.s );
             }
+            osso_rpc_free_val(&retval);
             return OSSO_RPC_ERROR;
 
         case OSSO_INVALID:  /* Invalid parameter (shouldn't happen) */
         default:
             ULOG_CRIT( "HelpLib: Unknown rc from HelpUI DBUS: %d\n", (int)rc );
+            osso_rpc_free_val(&retval);
             return OSSO_RPC_ERROR;  /* g_assert(FALSE); */
 
         case OSSO_OK:
@@ -528,11 +531,13 @@ osso_return_t ossohelp_show( osso_context_t* osso,
   } 
               
   #ifdef RPC_NOWAIT
-    return OSSO_OK;     /* always returns success */
+    ret = OSSO_OK;     /* always returns success */
   #else
-    g_assert( retval.type == DBUS_TYPE_BOOLEAN );
-    return (retval.value.b) ? OSSO_OK : OSSO_ERROR;   /* was the URL found? */
+    ret = (( retval.type == DBUS_TYPE_BOOLEAN ) && retval.value.b)
+        ? OSSO_OK : OSSO_ERROR;   /* was the URL found? */
   #endif
+    osso_rpc_free_val(&retval);
+    return ret;
 }
 
 
@@ -630,11 +635,19 @@ gboolean ossohelp_dialog_help_enable( GtkDialog *dialog,
                                       const gchar *topic,
                                       osso_context_t *osso )
 {
-    gulong sigid = -1;
+    gulong sigid;
+    gulong *sigid_p;
     if (!dialog)
         return FALSE;   /* bad parameters */
 
     g_object_set_data(G_OBJECT(dialog), "help-topic", NULL);
+    sigid_p = (gulong*) g_object_get_data(G_OBJECT(dialog), "help-signal");
+
+    if (sigid_p) {
+        sigid = *sigid_p;
+    } else {
+        sigid = -1;
+    }
 
     /* If topic == NULL, disable the ? icon */
     if (!topic){
@@ -661,5 +674,9 @@ gboolean ossohelp_dialog_help_enable( GtkDialog *dialog,
     sigid = g_signal_connect( GTK_OBJECT (dialog), "help",
                       G_CALLBACK (on_help), (gpointer)osso);
 
+    sigid_p = g_new0(gulong, 1);
+    *sigid_p = sigid;
+    g_object_set_data_full(G_OBJECT(dialog), "help-signal", sigid_p, g_free);
+
     return TRUE;    
 }
